@@ -1,10 +1,14 @@
 library("R.filesets")
 
+message("*** sortBy() on GenericDataFile")
+
+# Example files
+path <- system.file("exData", "dataSetA,original", package="R.filesets")
+print(path)
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Setting up a file set
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-path <- system.file(package="R.filesets")
 ds <- GenericDataFileSet$byPath(path)
 print(ds)
 
